'use strict'
let Q = require('q')
let express = require('express')
let router = express.Router()
let _ = require('lodash')
let commons = require('@dct/commons')
let log = commons.Log.getLogger(__filename)
let _Error = commons._Error
let Response = commons.Rest.Response
const NotifyCronJob = require('../lib/asset-maintain/asset-maintain')
const uuid = require('uuid')
/**
 * 传入资产维保计划通知信息，创建cron job job
 */
router.post('/', (req, res) => {
  let plans = req.body
  Q()
    .tap(function () {
      // check argument
      if (!plans || !_.isArray(plans)) {
        throw new _Error('bad request. missing asset maintain plan notify  or asset maintain plan notify must be array in body')
      }
    })
    .then(function () {
      const promises = _.map(plans, plan => {
        return NotifyCronJob.createCronJob(plan)
      })
      return Q.all(promises)
    })
    .then(function (created) {
      Response.succeed(res, created)
    })
    .catch(function (err) {
      Response.fail(res, err)
    })
})
/**
 * 传入删除的taskId，停止正在执行的CronJob并删除
 */
router.delete('/', (req, res) => {
  const taskIds = req.body
  Q()
    .then(function () {
      return NotifyCronJob.deleteCronJobsByplanIds(taskIds)
    })
    .then(function (created) {
      Response.succeed(res, created)
    })
    .catch(function (err) {
      Response.fail(res, err)
    })
})
/**
 * 根据传入的planId,更新已经创建的CronJob 并重新启动
 */
router.put('/:planId', (req, res) => {
  const planId = req.params.planId
  const plan = req.body
  Q()
    .tap(function () {
      // check argumen
      if (!plan || !_.isObject(plan)) {
        throw new _Error('bad request. missing Regular check plan data in body')
      }
    })
    .then(function () {
      return NotifyCronJob.updateCronJob(planId, plan)
    })
    .then(function (created) {
      Response.succeed(res, created)
    })
    .catch(function (err) {
      Response.fail(res, err)
    })
})
/**
 * 批量更新维保计划通知
 */
router.put('/', (req, res) => {

  const plans = req.body
  Q()
    .tap(function () {
      // check argumen
      if (!plans || !_.isArray(plans)) {
        throw new _Error('bad request. missing Regular check plan data in body')
      }
    })
    .then(function () {
      const promises = _.map(plans, plan => {
        return NotifyCronJob.updateCronJob(plan.planId, plan)
      })
      return Q.all(promises)
    })
    .then(function (updated) {
      Response.succeed(res, updated)
    })
    .catch(function (err) {
      Response.fail(res, err)
    })
})

module.exports = router
